.. SwissFit documentation master file, created by
   sphinx-quickstart on Sat Jul 27 10:16:33 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

SwissFit
========

.. image:: ../../SwissFit_logo.png
   :align: center

.. include:: introduction.md
   :parser: commonmark

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   fit

